@@ -18,20 +18,21 @@ class Feedback(models.Model):
     content_type = models.ForeignKey(ContentType)
     object_id = models.TextField(_('object id'))
     content_object = generic.GenericForeignKey('content_type', 'object_id')
-    message = models.TextField(_('message'), blank=True)
     rating = models.PositiveSmallIntegerField(_('rating'),
                                               choices=RATING_CHOICES)
+    message = models.TextField(_('message'), blank=True)
 
     @models.permalink
     def get_absolute_url(self):
         return ('detail', (self.id,))
 
     @classmethod
-    def create(cls, user, obj):
+    def create(cls, user, obj, rating=None, message=""):
         return cls(user=user,
                    object_id=obj.id,
                    content_type=ContentType.objects.get_for_model(obj),
-                   rating=1)
+                   rating=rating,
+                   message=message)
 
     def unique_error_message(self, *args, **kwargs):
         return _('You have already given this feedback.')
