@@ -66,31 +66,33 @@ class FeedbackCreateView(CreateView):
         return super(FeedbackCreateView, self).post(request, *args, **kwargs)
 
 
-class FeedbackDetailMixin(object):
-    def get_rating_data(self):
-        obj = self.get_object()
+class RatingAggregatedData(object):
+    count = 0
+    average = 0
+    data = {}
 
-        class RatingAggregatedData(object):
-            count = 0
-            average = 0
-            data = dict([(5-x, {'count': 0,
-                                'percent': 0,
-                                'score': 5-x}) for x in range(5)])
+    def __init__(self, *args, **kwargs):
+        self.data = dict([(5-x, {'count': 0,
+                                 'percent': 0,
+                                 'score': 5-x}) for x in range(5)])
 
-            def update(self, rating, count):
-                self.data.get(rating)['count'] = count
-                total = self.count = self.average = 0
+    def update(self, rating, count):
+        self.data.get(rating)['count'] = count
+        total = self.count = self.average = 0
 
-                for score, data in self.data.iteritems():
-                    self.count += data['count']
-                    total += data['count']*score
+        for score, data in self.data.iteritems():
+            self.count += data['count']
+            total += data['count']*score
 
-                for score, data in self.data.iteritems():
-                    self.data.get(score)['percent'] = \
-                        (data['count']*100)//self.count
+        for score, data in self.data.iteritems():
+            self.data.get(score)['percent'] = \
+                (data['count']*100)//self.count
 
-                self.average = round(total / self.count, 1)
+        self.average = round(total / self.count, 1)
 
+
+class RatingDataMixin(object):
+    def get_rating_data(self, obj):
         rating_data = RatingAggregatedData()
 
         rating_queryset = Feedback.objects.filter(
@@ -104,8 +106,24 @@ class FeedbackDetailMixin(object):
 
         return rating_data
 
+
+class FeedbackDetailMixin(RatingDataMixin):
     def get_context_data(self, **kwargs):
         context_data = super(FeedbackDetailMixin,
                              self).get_context_data(**kwargs)
-        context_data.update({'rating_data': self.get_rating_data()})
+
+        context_data.get('object').rating_data = \
+            self.get_rating_data(self.object)
+
+        return context_data
+
+
+class FeedbackListMixin(RatingDataMixin):
+    def get_context_data(self, **kwargs):
+        context_data = super(FeedbackListMixin,
+                             self).get_context_data(**kwargs)
+
+        for obj in context_data.get('object_list'):
+            obj.rating_data = self.get_rating_data(obj)
+
         return context_data
